#!/bin/bash

### BEGIN INIT INFO
# Provides:          EndPointMonitor
# Required-Start:    $remote_fs $syslog $network
# Required-Stop:     $remote_fs $syslog $network
# Default-Start:     2 3 4 5
# Default-Stop:      0 1 6
# Short-Description: Start EndPoint Monitor
# Description:       Start/Stops SMNT EndPoint Monitor
### END INIT INFO

installationDirectory=/opt/smnt/endPointMonitor
logDirectory=/var/log/endPointMonitor
pidFile=$installationDirectory/endPointMonitor.pid
applicationUser=endPointMonitor
javaPath=java
maxMemory=2G
currentUser=`whoami`

cd $installationDirectory

case "$1" in
start)
	printf "%-120s" "Checking if SMNT EndPoint Monitor controller is already running..."

	if [ -f $pidFile ]
	then
		pid=`cat $pidFile`

		if [ -z "`ps axf | grep ${pid} | grep -v grep`" ]
		then
			printf "%s\n" "OK"
		else
			echo "Failed"
			exit 2
		fi
	else
		echo "OK"
	fi

	printf "%-120s" "Starting SMNT EndPoint Monitor controller..."

	if [[ $currentUser == $applicationUser ]]
	then
		nohup $javaPath -Xmx$maxMemory -Dlogging.config=$installationDirectory/config/log4j2.xml -jar $installationDirectory/endPointMonitor.war > $logDirectory/endPointMonitorInit.log 2>&1 & echo $! > $installationDirectory/endPointMonitor.pid
	else
		su $applicationUser -c "nohup $javaPath -Xmx$maxMemory -Dlogging.config=$installationDirectory/config/log4j2.xml -jar $installationDirectory/endPointMonitor.war > $logDirectory/endPointMonitorInit.log 2>&1" & echo $! > $installationDirectory/endPointMonitor.pid
	fi

	#Now we'll wait a few seconds, and then check the PID is still running.
	sleep 3

	if [ -f $pidFile ]
	then
		pid=`cat $pidFile`
		if [ -z "`ps axf | grep ${pid} | grep -v grep`" ]
		then
			echo "Failed"
			exit 2
		else
			echo "OK"
			exit 0
		fi
	else
		echo "Failed"
		exit 2
	fi
	;;
stop)
	printf "%-120s" "Checking SMNT EndPoint Monitor controller is running..."

	if [ -f $pidFile ]
	then
		pid=`cat $pidFile`
		if [ -z "`ps axf | grep ${pid} | grep -v grep`" ]
		then
			printf "%s\n" "Not running"
			exit 2
		else
			echo "OK"
		fi
	else
		echo "Not running"
		exit 0
	fi

	printf "%-120s" "Stopping SMNT EndPoint Monitor controller..."
	kill $pid
	rm -f $installationDirectory/endPointMonitor.pid
	echo "OK"
	;;

restart)
	$0 stop
	$0 start
	;;

status)
	printf "%-120s" "Checking SMNT EndPoint Monitor controller..."
	if [ -f $pidFile ]
	then
		pid=`cat $pidFile`
		if [ -z "`ps axf | grep ${pid} | grep -v grep`" ]
		then
			printf "%s\n" "EndPoint Monitor controller not running"
		else
			echo "Running"
		fi
	else
		printf "%s\n" "EndPoint Monitor controller not running"
	fi
	;;
*)
	echo "Usage: $0 {start|stop|restart|status}"
	exit 2
esac
